Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1521)

Unified Diff: content/browser/renderer_host/legacy_render_widget_host_win.h

Issue 2852763002: Added a system caret used for accessibility on Windows. (Closed)
Patch Set: Disabled all tests Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/BUILD.gn ('k') | content/browser/renderer_host/legacy_render_widget_host_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/renderer_host/legacy_render_widget_host_win.h
diff --git a/content/browser/renderer_host/legacy_render_widget_host_win.h b/content/browser/renderer_host/legacy_render_widget_host_win.h
index 91a02052432b235f8d5fe59cf65754cb08c81edd..b89060ed8022c6386e3fd3d9bafdc88bf2495a3e 100644
--- a/content/browser/renderer_host/legacy_render_widget_host_win.h
+++ b/content/browser/renderer_host/legacy_render_widget_host_win.h
@@ -24,7 +24,7 @@ class DirectManipulationHelper;
} // namespace gfx
namespace ui {
-class AXFakeCaretWin;
+class AXSystemCaretWin;
class WindowEventTarget;
}
@@ -121,7 +121,7 @@ class CONTENT_EXPORT LegacyRenderWidgetHostHWND
host_ = host;
}
// Changes the position of the fake caret.
void MoveCaretTo(const gfx::Rect& bounds);
protected:
@@ -164,7 +164,7 @@ class CONTENT_EXPORT LegacyRenderWidgetHostHWND
RenderWidgetHostViewAura* host_;
// Some assistive software need to track the location of the caret.
- std::unique_ptr<ui::AXFakeCaretWin> ax_fake_caret_;
+ std::unique_ptr<ui::AXSystemCaretWin> ax_system_caret_;
// This class provides functionality to register the legacy window as a
// Direct Manipulation consumer. This allows us to support smooth scroll
« no previous file with comments | « chrome/test/BUILD.gn ('k') | content/browser/renderer_host/legacy_render_widget_host_win.cc » ('j') | no next file with comments »
@@ -121,7 +121,7 @@ class CONTENT_EXPORT LegacyRenderWidgetHostHWND
host_ = host;
}
- // Changes the position of the fake caret.
+ // Changes the position of the system caret used for accessibility.
void MoveCaretTo(const gfx::Rect& bounds);
protected:

Powered by Google App Engine
This is Rietveld 408576698